#
# spec file for package python-pyproject-metadata
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pyproject-metadata
Version:        0.9.1
Release:        1.1
Summary:        PEP 621 metadata parsing
License:        MIT
URL:            https://github.com/FFY00/python-pyproject-metadata
Source:         https://github.com/FFY00/python-pyproject-metadata/archive/refs/tags/%{version}.tar.gz#/pyproject-metadata-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module packaging >= 19}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 42}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-packaging >= 19
BuildArch:      noarch
# SECTION test
BuildRequires:  %{python_module pytest}
%if 0%{python_version_nodots} < 311
BuildRequires:  %{python_module tomli >= 1.0.0}
%endif
# /SECTION
%python_subpackages

%description
Dataclass for PEP 621 metadata with support for core metadata generation

This project does not implement the parsing of `pyproject.toml`
containing PEP 621 metadata.

Instead, given a Python data structure representing PEP 621 metadata (already
parsed), it will validate this input and generate a PEP 643-compliant metadata
file (e.g. `PKG-INFO`).

%prep
%autosetup -p1 -n pyproject-metadata-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/pyproject_metadata
%{python_sitelib}/pyproject_metadata-%{version}*-info

%changelog
* Fri Mar 14 2025 Felix Stegmeier <felix.stegmeier@suse.com>
- Update to 0.9.1
  * Added PEP 639 support for SPDX license and license files, METADATA 2.4
  * Validate extra keys (warning, opt-in error)
  * Functions to check top level and build-system (including PEP 735 support)
  * Add TypedDict's in new module for typing pyproject.toml dicts
  * all_errors=True causes ExceptionGroup's to be emitted
  * Support METADATA 2.1+ JSON format with new .as_json() method
  * Handle multilines the way setuptools does with smart indentation
  * Warn on multiline Summary (project.description)
  * Improve locking for just metadata fields
  * Error on extra keys in author/maintainer
  * URL name stylization removed matching PEP 753
  * Handle form feed for Python <3.12.4
  * Some touchup based on packaging PR
* Thu Aug 17 2023 Markéta Machová <mmachova@suse.com>
- update to 0.7.1
  * Use UTF-8 when opening files
  * Use tomllib on Python >= 3.11
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Mon Jan  2 2023 Ben Greiner <code@bnavigator.de>
- Skip a test failing due to new error strings in packaging 22
  gh#FFY00/python-pyproject-metadata#41
* Sat Sep 10 2022 Ben Greiner <code@bnavigator.de>
- Initial specfile for v 0.6.1
- Required by meson-python
